==> apache-camel-4.13.0-src.zip: apache-camel-4.13.0/components/camel-aws/camel-aws2-sts/src/main/java/org/apache/camel/component/aws2/sts/client/STS2ClientFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.aws2.sts.client;

import org.apache.camel.component.aws2.sts.STS2Configuration;
import org.apache.camel.component.aws2.sts.client.impl.STS2ClientIAMOptimized;
import org.apache.camel.component.aws2.sts.client.impl.STS2ClientIAMProfileOptimized;
import org.apache.camel.component.aws2.sts.client.impl.STS2ClientStandardImpl;

/**
 * Factory class to return the correct type of AWS STS aws.
 */
public final class STS2ClientFactory {

    private STS2ClientFactory() {
    }

    /**
     * Return the correct aws STS client (based on remote vs local).
     *
     * @param  configuration configuration
     * @return               StsClient
     */
    public static STS2InternalClient getStsClient(STS2Configuration configuration) {
        if (Boolean.TRUE.equals(configuration.isUseDefaultCredentialsProvider())) {
            return new STS2ClientIAMOptimized(configuration);
        } else if (Boolean.TRUE.equals(configuration.isUseProfileCredentialsProvider())) {
            return new STS2ClientIAMProfileOptimized(configuration);
        } else {
            return new STS2ClientStandardImpl(configuration);
        }
    }
}

==> apache-camel-4.17.0-src.zip: apache-camel-4.17.0/components/camel-aws/camel-aws2-sts/src/main/java/org/apache/camel/component/aws2/sts/client/STS2ClientFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.aws2.sts.client;

import org.apache.camel.component.aws.common.AwsClientBuilderUtil;
import org.apache.camel.component.aws2.sts.STS2Configuration;
import software.amazon.awssdk.services.sts.StsClient;

/**
 * Factory class to create AWS STS clients using common configuration.
 */
public final class STS2ClientFactory {

    private STS2ClientFactory() {
    }

    /**
     * Create an STS client based on configuration.
     *
     * @param  configuration The STS configuration
     * @return               Configured StsClient
     */
    public static StsClient getStsClient(STS2Configuration configuration) {
        return AwsClientBuilderUtil.buildClient(
                configuration,
                StsClient::builder);
    }
}
